==> fetch.php?media=oais%3Adocuteam_packer-2.1.0.zip: ch/docuteam/tools/out/Logger.java <==
/**
 *	Copyright (C) 2011-2014 Docuteam GmbH
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 3
 *	as published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.docuteam.tools.out;



import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.xml.DOMConfigurator;
import org.slf4j.bridge.SLF4JBridgeHandler;

/**
 * This abstract class offers a convenient interface to Log4J.
 * It handles
 * <ol>
 * <li>The initialization of the Log4J system</li>
 * <li>Class-individual loggers</li>
 * </ol>
 *
 * <h3>Initialization</h3>
 * When this class is used for the 1st time, it initializes the Log4J System. Every subsequent usage does NOT initialize the Log4J System again.
 *
 * <h3>Class-Individual Loggers</h3>
 * When a class uses this class for logging, the appropriate logger is stored internally and reused on every subsequent log from that class.
 * <p>
 * NOTE: If a config file other than ./config/log4j.xml is used, set the config file with Logger.setConfigFile(String);
 *
 * @author denis
 */
public abstract class Logger
{
	//	=======================================================================
	//	==========	Structure			=======================================
	//	=======================================================================

	//	==========	Public Static		=======================================

	//	==========	Private Static		=======================================

	/**
	 * The default log4j configuration file location:
	 */
	private static final String								DefaultConfigFileName = "config/log4j.xml";

	private static URL										ConfigFileURL;

	private static Map<String, org.apache.log4j.Logger>		Loggers = new HashMap<String, org.apache.log4j.Logger>();
	private static Boolean									IsInitialized = false;
	private static Boolean									CouldNotInitialize = false;


	//	=======================================================================
	//	==========	Methods				=======================================
	//	=======================================================================

	//	==========	Public Static		=======================================

	//	--------		Initializing		-------------------------------------------------------

	public static void setConfigFile(String newConfigFile)
	{
		try
		{
			ConfigFileURL = new File(newConfigFile).toURI().toURL();
		}
		catch (MalformedURLException e)
		{
			e.printStackTrace();
			Tracer.error("Logger could not be initialized properly.");
		}

		//	(Re-)initialize with new ConfigFile:
		IsInitialized = false;
		initializeIfNecessary();
	}


	public static void setConfigFile(URL newConfigFile)
	{
		ConfigFileURL = newConfigFile;

		//	(Re-)initialize with new ConfigFile:
		IsInitialized = false;
		initializeIfNecessary();
	}


	/**
	 * When switching STDOUT and STDERR using System.setOut() and System.setErr(), DOMConfigurator must be reconfigured.
	 */
	public static void reInitialize()
	{
		IsInitialized = false;
		initializeIfNecessary();
	}

	//	--------		Logging				-------------------------------------------------------

	public static void trace()
	{
		if (CouldNotInitialize)		return;

		getLogger().trace("");
	}


	public static void trace(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().trace(message);
	}


	public static void trace(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().trace(message, t);
	}


	public static void debug()
	{
		if (CouldNotInitialize)		return;

		getLogger().debug("");
	}


	public static void debug(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().debug(message);
	}


	public static void debug(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().debug(message, t);
	}


	public static void info()
	{
		if (CouldNotInitialize)		return;

		getLogger().info("");
	}


	public static void info(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().info(message);
	}


	public static void info(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().info(message, t);
	}


	public static void warn(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().warn(message);
	}


	public static void warn()
	{
		if (CouldNotInitialize)		return;

		getLogger().warn("");
	}


	public static void warn(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().warn(message, t);
	}


	public static void error(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().error(message);
	}


	public static void error()
	{
		if (CouldNotInitialize)		return;

		getLogger().error("");
	}


	public static void error(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().error(message, t);
	}


	public static void fatal()
	{
		if (CouldNotInitialize)		return;

		getLogger().fatal("");
	}


	public static void fatal(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger().fatal(message);
	}


	public static void fatal(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger().fatal(message, t);
	}

	//	--------		Accessing			-------------------------------------------------------

	/**
	 * Get the logger with this name.
	 */
	public static org.apache.log4j.Logger getLogger(String name)
	{
		initializeIfNecessary();

		if (!Loggers.containsKey(name))		Loggers.put(name, org.apache.log4j.Logger.getLogger(name));

		return Loggers.get(name);
	}


	//	==========	Private Static		=======================================

	//	--------		Accessing			-------------------------------------------------------

	/**
	 * Get the logger for the calling class.
	 */
	private static org.apache.log4j.Logger getLogger()
	{
		return getLogger(Thread.currentThread().getStackTrace()[3].getClassName());
	}

	//	--------		Initializing		-------------------------------------------------------

	private static void initializeIfNecessary()
	{
		if (IsInitialized)		return;

		try
		{
			//	Redirect jul-logging to slf. With the lib "slf4j-log4j12" which we use, slf logging will be redirected to log4j:
			SLF4JBridgeHandler.removeHandlersForRootLogger();
			SLF4JBridgeHandler.install();

			//	Tell commons-logging to use log4j:
			System.setProperty("org.apache.commons.logging.LogFactory", "org.apache.commons.logging.impl.Log4jFactory");
			System.setProperty("org.apache.commons.logging.Log", "org.apache.commons.logging.impl.Log4JLogger");

			//	Initialize log4j:
			if (ConfigFileURL == null)		ConfigFileURL = new File(DefaultConfigFileName).toURI().toURL();
			DOMConfigurator.configure(ConfigFileURL);

			IsInitialized = true;
		}
		catch (java.lang.Exception ex)
		{
			ex.printStackTrace();
			Tracer.error("Logger could not be initialized properly.");

			CouldNotInitialize = true;
		}
	}

}

==> fetch.php?media=oais%3Adocuteam_packer-2.2.0.zip: ch/docuteam/tools/out/Logger.java <==
/**
 *	Copyright (C) 2011-2015 Docuteam GmbH
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 3
 *	as published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.docuteam.tools.out;



import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

import org.apache.log4j.xml.DOMConfigurator;
import org.slf4j.bridge.SLF4JBridgeHandler;

/**
 * This abstract class offers a convenient interface to Log4J.
 * It handles
 * <ol>
 * <li>The initialization of the Log4J system</li>
 * <li>Class-individual loggers</li>
 * </ol>
 *
 * <h3>Initialization</h3>
 * When this class is used for the 1st time, it initializes the Log4J System. Every subsequent usage does NOT initialize the Log4J System again.
 *
 * <h3>Class-Individual Loggers</h3>
 * When a class uses this class for logging, the appropriate logger is stored internally and reused on every subsequent log from that class.
 * <p>
 * NOTE: If a config file other than ./config/log4j.xml is used, set the config file with Logger.getLogger().setConfigFile(String);
 *
 * @author denis
 */
public abstract class Logger
{
	//	=======================================================================
	//	==========	Structure			=======================================
	//	=======================================================================

	//	==========	Public Static		=======================================

	//	==========	Private Static		=======================================

	/**
	 * The default log4j configuration file location:
	 */
	private static final String								DefaultConfigFileName = "config/log4j.xml";

	private static URL										ConfigFileURL;

	private static Map<String, org.apache.log4j.Logger>		Loggers = new HashMap<String, org.apache.log4j.Logger>();
	private static Boolean									IsInitialized = false;
	private static Boolean									CouldNotInitialize = false;


	//	=======================================================================
	//	==========	Methods				=======================================
	//	=======================================================================

	//	==========	Public Static		=======================================

	//	--------		Initializing		-------------------------------------------------------

	public static void setConfigFile(String newConfigFile)
	{
		try
		{
			ConfigFileURL = new File(newConfigFile).toURI().toURL();
		}
		catch (MalformedURLException e)
		{
			e.printStackTrace();
			Tracer.error("Logger could not be initialized properly.");
		}

		//	(Re-)initialize with new ConfigFile:
		IsInitialized = false;
		initializeIfNecessary();
	}


	public static void setConfigFile(URL newConfigFile)
	{
		ConfigFileURL = newConfigFile;

		//	(Re-)initialize with new ConfigFile:
		IsInitialized = false;
		initializeIfNecessary();
	}


	/**
	 * When switching STDOUT and STDERR using System.setOut() and System.setErr(), DOMConfigurator must be reconfigured.
	 */
	public static void reInitialize()
	{
		IsInitialized = false;
		initializeIfNecessary();
	}

	//	--------		Logging				-------------------------------------------------------

	public static void trace()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().trace("");
	}


	public static void trace(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().trace(message);
	}


	public static void trace(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().trace(message, t);
	}


	public static void debug()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().debug("");
	}


	public static void debug(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().debug(message);
	}


	public static void debug(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().debug(message, t);
	}


	public static void info()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().info("");
	}


	public static void info(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().info(message);
	}


	public static void info(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().info(message, t);
	}


	public static void warn(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().warn(message);
	}


	public static void warn()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().warn("");
	}


	public static void warn(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().warn(message, t);
	}


	public static void error(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().error(message);
	}


	public static void error()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().error("");
	}


	public static void error(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().error(message, t);
	}


	public static void fatal()
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().fatal("");
	}


	public static void fatal(Object message)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().fatal(message);
	}


	public static void fatal(Object message, Throwable t)
	{
		if (CouldNotInitialize)		return;

		getLogger_internal().fatal(message, t);
	}

	//	--------		Accessing			-------------------------------------------------------

	/**
	 * Get the logger for the calling class (to be used only from outside of this class).
	 */
	public static org.apache.log4j.Logger getLogger()
	{
		return getLogger(Thread.currentThread().getStackTrace()[2].getClassName());
	}


	/**
	 * Get the logger with this name.
	 */
	public static org.apache.log4j.Logger getLogger(String name)
	{
		initializeIfNecessary();

		if (!Loggers.containsKey(name))		Loggers.put(name, org.apache.log4j.Logger.getLogger(name));

		return Loggers.get(name);
	}

	//	==========	Private Static		=======================================

	//	--------		Accessing			-------------------------------------------------------

	/**
	 * Get the logger for the calling class (to be used only from inside of this class).
	 */
	private static org.apache.log4j.Logger getLogger_internal()
	{
		return getLogger(Thread.currentThread().getStackTrace()[3].getClassName());
	}

	//	--------		Initializing		-------------------------------------------------------

	private static void initializeIfNecessary()
	{
		if (IsInitialized)		return;

		try
		{
			//	Redirect jul-logging to slf. With the lib "slf4j-log4j12" which we use, slf logging will be redirected to log4j:
			SLF4JBridgeHandler.removeHandlersForRootLogger();
			SLF4JBridgeHandler.install();

			//	Tell commons-logging to use log4j:
			System.setProperty("org.apache.commons.logging.LogFactory", "org.apache.commons.logging.impl.Log4jFactory");
			System.setProperty("org.apache.commons.logging.Log", "org.apache.commons.logging.impl.Log4JLogger");

			//	Initialize log4j:
			if (ConfigFileURL == null)		ConfigFileURL = new File(DefaultConfigFileName).toURI().toURL();
			DOMConfigurator.configure(ConfigFileURL);

			IsInitialized = true;
		}
		catch (java.lang.Exception ex)
		{
			ex.printStackTrace();
			Tracer.error("Logger could not be initialized properly.");

			CouldNotInitialize = true;
		}
	}

}
